# `translatable(messages): (ContentComponent) => TranslatableContentComponent`

High order component factory that wraps your content component with supplied loader and pass prop `showLoader`
just to the loader

> ![Important](../alert-icon.png "Improtant note")
 To make HOC works properly, you must have `react-intl` installed just once!

### Arguments
1. `messages`: object with messages keyed by locale name, eg.

```js
const messages = {
    cs: {
        hello: 'Dobry den',
        ...
    },
    en: {
        hello: 'Hello',
        ...
    },
}
```

### Returns
Function that receives `ContentComponent` and return it wrapped with [IntlProvider](https://github.com/yahoo/react-intl/wiki/Components#intlprovider) and set locale to that given from
`store.translate.locale` store path.

> To make everything work properly you also need to set locale data using `addLocaleData` function from
`react-intl` package. See the snippet example below for example of how to do it.

### Examples

```jsx
import { FormattedMessage, addLocaleData } from 'react-intl';
import cs from 'react-intl/locale-data/cs';

import translatable from '../../src/HOC/translatable';

addLocaleData([...cs]);

const ContentComponent = () => (
    <div>
        <h1><FormattedMessage id="hello" /></h1>
        <h2><FormattedMessage id="bye.instant" /></h2>
        <h3><FormattedMessage id="bye.forever" /></h3>
    </div>
);

const messages = {
    cs: {
        hello: 'Cau',
        'bye.instant': 'Nashledanou',
        'bye.forever': 'Sbohem',
    },
};

const store = createStore((state = initialState) => ({
    translate: { locale: 'cs' },
}));

storiesOf('Translatable', module)
    .add('simple', () => {
        const TranslatableComponent = translatable(messages)(ContentComponent);
        return <TranslatableComponent store={store} />;
    });

```
