import React from 'react';
import PropTypes from 'prop-types';

import { connect } from 'react-redux';
import { IntlProvider } from 'react-intl';

import { getDisplayName } from '../helpers';

import { translateSelector } from '../selectors';

var translatable = function translatable(messages) {
    return function (TranslatableComponent) {
        var Component = function Component(props) {
            return React.createElement(
                IntlProvider,
                {
                    locale: props.locale,
                    messages: messages[props.locale]
                },
                React.createElement(TranslatableComponent, props)
            );
        };

        Component.displayName = 'Translatable(' + getDisplayName(TranslatableComponent) + ')';
        Component.propTypes = {
            locale: PropTypes.string.isRequired
        };

        return connect(function (state) {
            return translateSelector(state);
        })(Component);
    };
};

export default translatable;