var _handlers;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _marked = /*#__PURE__*/regeneratorRuntime.mark(sendMessage),
    _marked2 = /*#__PURE__*/regeneratorRuntime.mark(createTextMessage),
    _marked3 = /*#__PURE__*/regeneratorRuntime.mark(createImageMessage),
    _marked4 = /*#__PURE__*/regeneratorRuntime.mark(setSeenMessages),
    _marked5 = /*#__PURE__*/regeneratorRuntime.mark(toggleUserOnline),
    _marked6 = /*#__PURE__*/regeneratorRuntime.mark(changeDisplayType),
    _marked7 = /*#__PURE__*/regeneratorRuntime.mark(_callee);

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import { all, select, put, takeEvery } from 'redux-saga/effects';
import { authUser } from 'redux-token-auth';
import { getFirebase } from 'react-redux-firebase';
import { push } from 'react-router-redux';
import { uploadImage } from 'ackee-image-server';
import { isEmpty } from 'lodash';

import actionTypes from '../actions/actionTypes';
import { appActions, chatActions, loggingActions } from '../actions/actions';
import { chatConstants } from '../constants/constants';
import config from '../config/config';

import { runSagas } from './helpers';
import { unseenSelector, messagesSelector } from '../selectors';
import { getUserFirebaseId } from '../utilities/chat';

function sendMessage(conversationId, message, unseen, reset) {
    var _getFirebase$database, key;

    return regeneratorRuntime.wrap(function sendMessage$(_context) {
        while (1) {
            switch (_context.prev = _context.next) {
                case 0:
                    _context.prev = 0;

                    if (!(typeof reset === 'function')) {
                        _context.next = 4;
                        break;
                    }

                    _context.next = 4;
                    return reset();

                case 4:
                    key = getFirebase().database().ref(config.firebase.conversationMessages(conversationId).path).push().key;
                    _context.next = 7;
                    return getFirebase().database().ref().update((_getFirebase$database = {}, _defineProperty(_getFirebase$database, config.firebase.conversationMessages(conversationId).path + '/' + key, _extends({}, message, {
                        unseen: unseen
                    })), _defineProperty(_getFirebase$database, config.firebase.conversationLastMessage(conversationId).path, message), _getFirebase$database));

                case 7:
                    _context.next = 9;
                    return put(chatActions.setSeenMessages(conversationId));

                case 9:
                    _context.next = 11;
                    return put(appActions.incSentMessages());

                case 11:
                    _context.next = 20;
                    break;

                case 13:
                    _context.prev = 13;
                    _context.t0 = _context['catch'](0);
                    _context.next = 17;
                    return put(appActions.setErrorAlert('alerts.chat.message.create.error'));

                case 17:
                    _context.next = 19;
                    return put(loggingActions.logError(_context.t0));

                case 19:
                    throw _context.t0;

                case 20:
                case 'end':
                    return _context.stop();
            }
        }
    }, _marked, this, [[0, 13]]);
}

function createTextMessage(params) {
    var _params$data, conversationId, text, reset, startSubmit, stopSubmit, user, unseen, message;

    return regeneratorRuntime.wrap(function createTextMessage$(_context2) {
        while (1) {
            switch (_context2.prev = _context2.next) {
                case 0:
                    _params$data = params.data, conversationId = _params$data.conversationId, text = _params$data.text, reset = params.reset, startSubmit = params.startSubmit, stopSubmit = params.stopSubmit;
                    _context2.next = 3;
                    return select(authUser);

                case 3:
                    user = _context2.sent;
                    _context2.next = 6;
                    return select(unseenSelector);

                case 6:
                    unseen = _context2.sent;
                    message = {
                        author: getUserFirebaseId(user),
                        time: new Date().getTime(),
                        text: text
                    };
                    _context2.next = 10;
                    return sendMessage(conversationId, message, unseen(conversationId), reset);

                case 10:
                case 'end':
                    return _context2.stop();
            }
        }
    }, _marked2, this);
}

function createImageMessage(params) {
    var image, conversationId, name, uploadedImage, user, unseen, message;
    return regeneratorRuntime.wrap(function createImageMessage$(_context3) {
        while (1) {
            switch (_context3.prev = _context3.next) {
                case 0:
                    image = params.image, conversationId = params.conversationId;
                    name = new Date().getTime().toString() + conversationId;
                    _context3.prev = 2;
                    _context3.next = 5;
                    return uploadImage(config.imageServer.apiUrl, config.imageServer.apiKey, config.imageServer.folder + name.replace(/[_,.-]/g, ''), image);

                case 5:
                    uploadedImage = _context3.sent;
                    _context3.next = 8;
                    return select(authUser);

                case 8:
                    user = _context3.sent;
                    _context3.next = 11;
                    return select(unseenSelector);

                case 11:
                    unseen = _context3.sent;
                    message = {
                        author: getUserFirebaseId(user),
                        time: new Date().getTime(),
                        image: uploadedImage.key
                    };
                    _context3.next = 15;
                    return sendMessage(conversationId, message, unseen(conversationId));

                case 15:
                    _context3.next = 24;
                    break;

                case 17:
                    _context3.prev = 17;
                    _context3.t0 = _context3['catch'](2);
                    _context3.next = 21;
                    return put(appActions.setErrorAlert('alerts.chat.image.upload.error'));

                case 21:
                    _context3.next = 23;
                    return put(loggingActions.logError(_context3.t0));

                case 23:
                    throw _context3.t0;

                case 24:
                case 'end':
                    return _context3.stop();
            }
        }
    }, _marked3, this, [[2, 17]]);
}

function setSeenMessages(params) {
    var conversationId, user, allMessages, ref, messages, userId, refs;
    return regeneratorRuntime.wrap(function setSeenMessages$(_context4) {
        while (1) {
            switch (_context4.prev = _context4.next) {
                case 0:
                    conversationId = params.conversationId;
                    _context4.next = 3;
                    return select(authUser);

                case 3:
                    user = _context4.sent;
                    _context4.next = 6;
                    return select(messagesSelector);

                case 6:
                    allMessages = _context4.sent;
                    ref = '' + config.firebase.conversationMessages(conversationId).path;
                    messages = allMessages(conversationId).messages;

                    if (!(messages && user)) {
                        _context4.next = 15;
                        break;
                    }

                    userId = getUserFirebaseId(user);
                    refs = messages.reduce(function (acc, message) {
                        if (Object.keys(message.unseen || {}).includes(userId)) {
                            acc['/' + message.key + '/unseen/' + userId] = null;
                        }
                        return acc;
                    }, {});

                    if (isEmpty(refs)) {
                        _context4.next = 15;
                        break;
                    }

                    _context4.next = 15;
                    return getFirebase().database().ref(ref).update(refs);

                case 15:
                case 'end':
                    return _context4.stop();
            }
        }
    }, _marked4, this);
}

function toggleUserOnline(params) {
    var online, user, ref;
    return regeneratorRuntime.wrap(function toggleUserOnline$(_context5) {
        while (1) {
            switch (_context5.prev = _context5.next) {
                case 0:
                    online = params.online;
                    _context5.next = 3;
                    return select(authUser);

                case 3:
                    user = _context5.sent;
                    ref = '' + config.firebase.user(getUserFirebaseId(user)).path;
                    _context5.next = 7;
                    return getFirebase().database().ref(ref).update({
                        online: online
                    });

                case 7:
                case 'end':
                    return _context5.stop();
            }
        }
    }, _marked5, this);
}

function changeDisplayType(_ref) {
    var displayType = _ref.displayType;
    return regeneratorRuntime.wrap(function changeDisplayType$(_context6) {
        while (1) {
            switch (_context6.prev = _context6.next) {
                case 0:
                    if (!(displayType === chatConstants.DISPLAY_DRIVERS)) {
                        _context6.next = 5;
                        break;
                    }

                    _context6.next = 3;
                    return put(push('/zpravy/ridici'));

                case 3:
                    _context6.next = 7;
                    break;

                case 5:
                    _context6.next = 7;
                    return put(push('/zpravy/kam'));

                case 7:
                case 'end':
                    return _context6.stop();
            }
        }
    }, _marked6, this);
}

var handlers = (_handlers = {}, _defineProperty(_handlers, actionTypes.chat.CREATE_TEXT_MESSAGE, createTextMessage), _defineProperty(_handlers, actionTypes.chat.CREATE_IMAGE_MESSAGE, createImageMessage), _defineProperty(_handlers, actionTypes.chat.TOGGLE_USER_ONLINE, toggleUserOnline), _handlers);

export default function _callee() {
    return regeneratorRuntime.wrap(function _callee$(_context7) {
        while (1) {
            switch (_context7.prev = _context7.next) {
                case 0:
                    _context7.next = 2;
                    return all([runSagas(handlers), takeEvery(actionTypes.chat.SET_SEEN_MESSAGES, setSeenMessages), takeEvery(actionTypes.chat.CHANGE_DISPLAY_TYPE, changeDisplayType)]);

                case 2:
                    return _context7.abrupt('return', _context7.sent);

                case 3:
                case 'end':
                    return _context7.stop();
            }
        }
    }, _marked7, this);
}