var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

import { createSelector, firebaseSelector, formValueSelector, _get, _has, _filter, _isString, _orderBy, populate } from './dependencies';

import constants from './chatConstants';
import * as paths from './firebase/paths';

var userIdFromPropsSelector = function userIdFromPropsSelector(state, props) {
    return props.userId;
};
/*
// eslint-disable-next-line
export const unseenSelector = createSelector([
    authUser,
    firebaseSelector,
], (user, firebase) => (id) => {
    const conversation = _.get(
        firebase,
        `data.${config.firebase.conversation(id).store}`,
        {}
    );
    const users = _.get(conversation, 'users');
    const userId = getUserFirebaseId(user);
    const unseen = {};
    if (!isEmpty(users)) {
        Object.keys(users).forEach(key => {
            if (key !== userId) {
                unseen[key] = true;
            }
        });
    }
    return unseen;
});

export const firebaseUserSelector = createSelector([
    firebaseSelector,
    simplifiedDriversSelector,
], (firebase, { drivers }) => (id) => {
    let tripId = null;
    if (typeof id === 'string') {
        const [userPrefix, userId] = id.split('_');
        if (userPrefix === chatConstants.Prefixes.DRIVER) {
            const driver = drivers.find(item => item.id === Number(userId));
            if (driver) {
                tripId = _.get(driver, 'activeTrip.id');
            }
        }
    }
    const user = _.get(
        firebase,
        `data.${config.firebase.user(id).store}`,
        {}
    );
    return ({
        isEmpty: isEmpty(user),
        isLoaded: isLoaded(user),
        user: {
            ...user,
            tripId,
        },
    });
});

export const messagesSelector = createSelector([
    firebaseSelector,
], (firebase) => (id) => {
    const messages = (_.get(
        firebase,
        `ordered.${config.firebase.conversationMessages(id).store}`,
        []
    ) || []).map(item => ({
        ...item.value,
        key: item.key,
    }));
    return ({
        isEmpty: isEmpty(messages),
        isLoaded: isLoaded(messages),
        messages,
    });
});*/

/**
 * Selects last message of every conversation
 * With active trip of driver that the conversation is about
 */
/* export const fullLastMessagesSelector = createSelector([
    authUser,
    firebaseSelector,
    simplifiedDriversSelector,
], (user, firebase, { drivers }) => {
    const userId = getUserFirebaseId(user);

    const userConversations = populate(
        firebase,
        config.firebase.userConversations(userId).store,
        config.firebase.populates.conversations,
    );

    return _.filter(userConversations, userConversation => _.has(userConversation, 'conversation.lastMessage'))
        .map(userConversation => ({
            conversationId: _.get(userConversation, 'conversation.id'),
            ..._.get(userConversation, 'conversation.lastMessage'),
        }))
        .map(message => {
            const [userPrefix, id] = message.conversationId.split('_');
            if (userPrefix === chatConstants.Prefixes.DRIVER) {
                const driver = drivers.find(item => item.id === Number(id));
                if (driver) {
                    message.tripId = _.get(driver, 'activeTrip.id');
                }
            }
            return message;
        })
        .sort((a, b) => (a.time < b.time));
});*/

export var userConversationsSelector = createSelector(userIdFromPropsSelector, firebaseSelector, function (userId, firebase) {
    var userConversations = populate(firebase, paths.userConversations(userId).store, paths.populates.conversations);

    var activeUserConversations = _filter(userConversations, function (userConversation) {
        return _has(userConversation, 'conversation');
    }).map(function (userConversation) {
        var conversation = userConversation.conversation;


        return _extends({
            conversationId: _isString(conversation) ? conversation : conversation.id
        }, userConversation);
    });

    return activeUserConversations;
});

var hasUnseenMessages = function hasUnseenMessages(conversation) {
    return Boolean(conversation.unseenMessagesCount > 0);
};
var isUnseenMoreRecent = function isUnseenMoreRecent(conversation) {
    return _get(conversation, ['lastMessage', 'time'], 0);
};

export var conversationsSelector = createSelector(userConversationsSelector, function (userConversations) {
    var conversations = userConversations.map(function (_ref) {
        var conversationId = _ref.conversationId,
            unseenMessagesCount = _ref.unseenMessagesCount,
            conversation = _ref.conversation;
        return {
            conversationId: conversationId,
            lastMessage: _get(conversation, 'lastMessage'),
            unseenMessagesCount: unseenMessagesCount
        };
    });

    conversations = _orderBy(conversations, [hasUnseenMessages, isUnseenMoreRecent], ['desc', 'desc']);

    return {
        isEmpty: conversations.legth === 0,
        isLoaded: true, // TODO,
        conversations: conversations
    };
});

var conversationsSearchFormSelector = formValueSelector(constants.SEARCH_CONVERSATION_FORM_ID);

export var conversationsSearchValueSelector = function conversationsSearchValueSelector(state) {
    return conversationsSearchFormSelector(state, 'text');
};

var firebaseUsersSelector = createSelector(firebaseSelector, function (firebase) {
    return _get(firebase, 'data.' + paths.users().store, {});
});

var isConversationMatchedByFilter = function isConversationMatchedByFilter(_ref2, filterValue) {
    var user = _ref2.user;

    var userName = _get(user, 'name');
    return _isString(userName) && userName.toLowerCase().includes(filterValue.toLowerCase());
};

export var conversationsListSelector = createSelector(conversationsSelector, firebaseUsersSelector, firebaseSelector, conversationsSearchValueSelector, function (_ref3, users, firebase, searchFormValue) {
    var conversations = _ref3.conversations;

    var conversationsList = conversations.map(function (conversation) {
        var conversationId = conversation.conversationId;

        var conversationDetail = _get(firebase, 'data.' + paths.conversation(conversationId).store, {});

        var user = users[conversationId];
        var authorId = _get(conversation, 'lastMessage.author');
        var author = users[authorId];

        return {
            conversation: _extends({}, conversation, conversationDetail),
            user: _extends({}, user, {
                id: conversationId
            }),
            author: _extends({}, author, {
                id: authorId
            })
        };
    });

    if (searchFormValue) {
        return conversationsList.filter(function (conversation) {
            return isConversationMatchedByFilter(conversation, searchFormValue);
        });
    }

    return conversationsList;
});

/* export const conversationSelector = createSelector(
    conversationsListSelector,
    (conversations) => (id) => {
        const conversation = _.get(
            conversations.find(c => c.conversation.id === id),
            'conversation',
            {}
        );

        return ({
            isEmpty: false,
            isLoaded: Boolean(conversation.id),
            conversation: {
                ...conversation,
                id,
            },
        });
    }
);

export const unseenConversationsSelector = createSelector(
    userConversationsSelector,
    userConversations => {
        return userConversations.filter(userConversation => {
            return _.get(userConversation, 'unseenMessagesCount', 0) > 0;
        });
    }
);

export const unseenConversationsCountsSelector = createSelector(
    unseenConversationsSelector,
    unseenUserConversations => {
        const initialUnseenCounts = {
            [chatConstants.Prefixes.DRIVER]: 0,
            [chatConstants.Prefixes.KAM]: 0,
        };

        return unseenUserConversations.reduce((unseenCounts, userConversation) => {
            unseenCounts[getUserPrefix(userConversation.conversationId)] += 1;
            return unseenCounts;
        }, initialUnseenCounts);
    }
);

export const chatPagingSelector = state => state.app.chat;

export const chatDisplayTypeSelector = createSelector(
    chatTypeSelector,
    type => {
        if (type === chatConstants.Prefixes.DRIVER) {
            return chatConstants.DISPLAY_DRIVERS;
        }
        return chatConstants.DISPLAY_KAM;
    }
);*/