import React from 'react';

import PropTypes from 'prop-types';
import { FormattedHTMLMessage, FormattedMessage } from 'react-intl';

import TopBar, { position } from '../TopBar/TopBar';
import Buttons from '../Widgets/ToggleButtonsGroup';

import { chatConstants } from '../../constants/constants';

var texts = {
    title: React.createElement(FormattedMessage, { id: 'chat.title' }),
    drivers: {
        unseen: function unseen(_unseen) {
            return React.createElement(FormattedHTMLMessage, { id: 'chat.display.drivers.unseen', values: { unseen: _unseen } });
        },
        seen: React.createElement(FormattedMessage, { id: 'chat.display.drivers.seen' })
    },
    kam: {
        unseen: function unseen(_unseen2) {
            return React.createElement(FormattedHTMLMessage, { id: 'chat.display.kam.unseen', values: { unseen: _unseen2 } });
        },
        seen: React.createElement(FormattedMessage, { id: 'chat.display.kam.seen' })
    }
};

var Chat = function Chat(_ref) {
    var children = _ref.children,
        isEmpty = _ref.isEmpty,
        isLoaded = _ref.isLoaded,
        unseenConversations = _ref.unseenConversations,
        isUserKam = _ref.isUserKam,
        displayType = _ref.displayType,
        changeDisplayType = _ref.changeDisplayType;
    return React.createElement(
        'div',
        { className: 'chat' },
        React.createElement(
            TopBar,
            { title: texts.title, contentPosition: position.MIDDLE },
            !isUserKam && React.createElement(Buttons, {
                activeButtonId: displayType,
                buttons: [{
                    id: chatConstants.DISPLAY_DRIVERS,
                    label: unseenConversations.driver > 0 ? texts.drivers.unseen(unseenConversations.driver) : texts.drivers.seen
                }, {
                    id: chatConstants.DISPLAY_KAM,
                    label: unseenConversations.kam > 0 ? texts.kam.unseen(unseenConversations.kam) : texts.kam.seen
                }],
                onChange: changeDisplayType
            })
        ),
        isLoaded && !isEmpty && React.cloneElement(children, { isUserKam: isUserKam })
    );
};

Chat.propTypes = {
    children: PropTypes.node.isRequired,
    isEmpty: PropTypes.bool.isRequired,
    isLoaded: PropTypes.bool.isRequired,
    unseenConversations: PropTypes.shape({
        kam: PropTypes.number,
        driver: PropTypes.number,
        dispatcher: PropTypes.number
    }).isRequired,
    changeDisplayType: PropTypes.func.isRequired,
    displayType: PropTypes.oneOf([chatConstants.DISPLAY_DRIVERS, chatConstants.DISPLAY_KAM]).isRequired,
    isUserKam: PropTypes.bool.isRequired
};

export default Chat;