'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _reactIntl = require('react-intl');

var _TopBar = require('../TopBar/TopBar');

var _TopBar2 = _interopRequireDefault(_TopBar);

var _ToggleButtonsGroup = require('../Widgets/ToggleButtonsGroup');

var _ToggleButtonsGroup2 = _interopRequireDefault(_ToggleButtonsGroup);

var _constants = require('../../constants/constants');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var texts = {
    title: _react2.default.createElement(_reactIntl.FormattedMessage, { id: 'chat.title' }),
    drivers: {
        unseen: function unseen(_unseen) {
            return _react2.default.createElement(_reactIntl.FormattedHTMLMessage, { id: 'chat.display.drivers.unseen', values: { unseen: _unseen } });
        },
        seen: _react2.default.createElement(_reactIntl.FormattedMessage, { id: 'chat.display.drivers.seen' })
    },
    kam: {
        unseen: function unseen(_unseen2) {
            return _react2.default.createElement(_reactIntl.FormattedHTMLMessage, { id: 'chat.display.kam.unseen', values: { unseen: _unseen2 } });
        },
        seen: _react2.default.createElement(_reactIntl.FormattedMessage, { id: 'chat.display.kam.seen' })
    }
};

var Chat = function Chat(_ref) {
    var children = _ref.children,
        isEmpty = _ref.isEmpty,
        isLoaded = _ref.isLoaded,
        unseenConversations = _ref.unseenConversations,
        isUserKam = _ref.isUserKam,
        displayType = _ref.displayType,
        changeDisplayType = _ref.changeDisplayType;
    return _react2.default.createElement(
        'div',
        { className: 'chat' },
        _react2.default.createElement(
            _TopBar2.default,
            { title: texts.title, contentPosition: _TopBar.position.MIDDLE },
            !isUserKam && _react2.default.createElement(_ToggleButtonsGroup2.default, {
                activeButtonId: displayType,
                buttons: [{
                    id: _constants.chatConstants.DISPLAY_DRIVERS,
                    label: unseenConversations.driver > 0 ? texts.drivers.unseen(unseenConversations.driver) : texts.drivers.seen
                }, {
                    id: _constants.chatConstants.DISPLAY_KAM,
                    label: unseenConversations.kam > 0 ? texts.kam.unseen(unseenConversations.kam) : texts.kam.seen
                }],
                onChange: changeDisplayType
            })
        ),
        isLoaded && !isEmpty && _react2.default.cloneElement(children, { isUserKam: isUserKam })
    );
};

Chat.propTypes = {
    children: _propTypes2.default.node.isRequired,
    isEmpty: _propTypes2.default.bool.isRequired,
    isLoaded: _propTypes2.default.bool.isRequired,
    unseenConversations: _propTypes2.default.shape({
        kam: _propTypes2.default.number,
        driver: _propTypes2.default.number,
        dispatcher: _propTypes2.default.number
    }).isRequired,
    changeDisplayType: _propTypes2.default.func.isRequired,
    displayType: _propTypes2.default.oneOf([_constants.chatConstants.DISPLAY_DRIVERS, _constants.chatConstants.DISPLAY_KAM]).isRequired,
    isUserKam: _propTypes2.default.bool.isRequired
};

exports.default = Chat;