import React from 'react';
import { createStore } from 'redux';
import { FormattedMessage, addLocaleData } from 'react-intl';
import cs from 'react-intl/locale-data/cs';

import { storiesOf } from '@storybook/react';
import { withInfo } from '@storybook/addon-info';

import translatable from '../../src/HOC/translatable';

addLocaleData([...cs]);

const messages = {
    cs: {
        foo: 'Ano, ja jsem foo',
        'bar.baz': 'Ne, ja jsem bar baz',
    },
    en: {
        foo: 'Yeah, I am foo',
        'bar.baz': 'No, I am baz',
    },
};

const initialState = {
    translate: { locale: 'cs' },
};
const store = createStore((state = initialState, action) => {
    if (action.type === 'CHANGE_LOCALE') {
        return {
            translate: { locale: action.locale },
        };
    }
    return state;
});

const localeChangeHandler = (e) => store.dispatch({ type: 'CHANGE_LOCALE', locale: e.target.value });

const ContentComponent = () => (
    <div>
        <div>
            cs <input type="radio" name="locale" value="cs" defaultChecked onClick={localeChangeHandler} />
        </div>
        <div>
            en <input type="radio" name="locale" value="en" onClick={localeChangeHandler} />
        </div>
        <h1><FormattedMessage id="foo" /></h1>
        <h2><FormattedMessage id="bar.baz" /></h2>
    </div>
);

storiesOf('Translatable', module)
    .add('simple', withInfo()(() => {
        const TranslatableComponent = translatable(messages)(ContentComponent);
        return <TranslatableComponent store={store} />;
    }));
